/*! \file cardimage.c \brief RawRead Sectors */
//###########################################################
///	\code #include "dos.h" \endcode
///	\par Uebersicht
//#########################################################################
// File: cardimage.c
//
// Liest Sektoren von der CF/MMC/SD und gibt sie
// ber RS232 als HEX-Listing aus.
//
// 115200 Baud, 8 Bit, 1 Stopbit, kein Parity, kein Handshake
//
//#########################################################################
// Last change: 29.07.2005
//#########################################################################
// hk@holger-klabunde.de
// http://www.holger-klabunde.de/index.html
//#########################################################################
// Compiler: AVR-GCC 3.4.3
//#########################################################################
//@{
#include <avr/io.h>
#include <avr/interrupt.h>
//#include <avr/signal.h>
#include <stdarg.h>
#include <string.h>
#include <stdlib.h>

#include "mydefs.h"
#include "../dos.h"
#include "../lcd.h"
#include "../printf.h"
#include "../serial.h"

//"volatile" fr alle Variablen die in Interrupt's gendert werden
unsigned int volatile countclock;

/*!\brief Cardimage main loop
*/
//###################################################################################
/* Hauptprogramm */
int main(void)
//###################################################################################
{
 DDRC=0xFF;  	// set io-pins on PortC
 PORTC=0; 	//LCD-Datenbus

 DDRD=0xF2;  	// set io-pins on PortD
 PORTD=0x02; 	//LCD-Steuersignale siehe lcd.h

 DDRA=0; 	//Alles Eingnge
 PORTA=0xFF; 	//Eingnge mit Pullups setzen

#ifdef COMPACTFLASH_CARD
 DDRB=0xFF; 	//Alles Ausgnge
 PORTB=0xFF; 	
#endif

#ifdef MMC_CARD_SPI
 MMC_IO_Init();
#endif

 SFIOR&=!(1<<PUD); 	//Pullups Enable
// SFIOR=0; 	//Pullups Enable

 ser_init();

 sei();              //enable interrupts

 RED_ON();
 GREEN_OFF();

 if(GetDriveInformation()!=F_OK) // get drive parameters
  {
   puts("Flash meldet sich nicht !");
   RED_OFF();
   GREEN_ON();
   while(1);
  }
  
   int i,j,k;
   unsigned long adress;
   unsigned char *p,by;
   
   adress=0;
   
   printf("%08X ",adress);

   for(k=0; k<40; k++) //Change number of sectors here
    {
     ReadSector(k,dirbuf);

     p=dirbuf;
 
     for(i=0; i<BYTE_PER_SEC; i++)
      {
       by=*p++;

       printf("%02X ",by);
       if(i%16==15)
        {
         adress+=16;
         ser_putc(' ');
         ser_putc(' ');
         for(j=0; j<16; j++)
          {
           by=p[-16+j];
           if(by<0x20) by='.';
           ser_putc(by);
          }// for j
      
         printf("\n%08X ",adress);
        } 
       }//for i

    } //for k

 GREEN_ON();
 RED_OFF();
 cli(); // Disable interrupts
 
 for(;;) // loop forever
  {
  }
}

